@@ -35,8 +35,11 @@ struct sis1100_global {
 #endif
 } sis1100_global;
 
-
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,18)
 struct pci_device_id sis1100_table[] __devinitconst={
+#else
+struct pci_device_id sis1100_table[] __devinit={
+#endif
     {
     PCI_VENDOR_FZJZEL, PCI_PRODUCT_FZJZEL_GIGALINK,
     PCI_ANY_ID, PCI_ANY_ID,
